@@ -69,15 +69,15 @@ def do_lock(
         locked_repo = project.locked_repository
         repo = project.get_repository()
         mapping: dict[str, Candidate] = {}
-        dependencies: dict[str, list[Requirement]] = {}
+        dependencies: dict[tuple[str, str | None], list[Requirement]] = {}
         with project.core.ui.open_spinner("Re-calculating hashes..."):
             for key, candidate in locked_repo.packages.items():
                 reqs, python_requires, summary = locked_repo.candidate_info[key]
                 candidate.summary = summary
                 candidate.requires_python = python_requires
-                ident = cast(str, key[0])
-                mapping[ident] = candidate
-                dependencies[ident] = list(map(parse_requirement, reqs))
+                dep_key = cast("tuple[str, str | None]", key[:2])
+                mapping[dep_key[0]] = candidate
+                dependencies[dep_key] = list(map(parse_requirement, reqs))
             fetch_hashes(repo, mapping)
             lockfile = format_lockfile(project, mapping, dependencies)
         project.write_lockfile(lockfile)
@@ -275,9 +275,10 @@ def do_add(
             req.specifier = get_specifier("")
     group_deps.update(requirements)
     reqs = [r for deps in all_dependencies.values() for r in deps.values()]
-    resolved = do_lock(
-        project, strategy, tracked_names, reqs, dry_run=dry_run, hooks=hooks
-    )
+    with hooks.skipping("post_lock"):
+        resolved = do_lock(
+            project, strategy, tracked_names, reqs, dry_run=dry_run, hooks=hooks
+        )
 
     # Update dependency specifiers and lockfile hash.
     deps_to_update = group_deps if unconstrained else requirements
@@ -285,6 +286,7 @@ def do_add(
     if not dry_run:
         project.add_dependencies(deps_to_update, group, dev)
         project.write_lockfile(project.lockfile, False)
+        hooks.try_emit("post_lock", resolution=resolved, dry_run=dry_run)
     _populate_requirement_names(group_deps)
     if sync:
         do_sync(
@@ -384,6 +386,13 @@ def do_update(
     )
     for deps in updated_deps.values():
         _populate_requirement_names(deps)
+    if unconstrained and not dry_run:
+        # Need to update version constraints
+        save_version_specifiers(updated_deps, resolved, save)
+        for group, deps in updated_deps.items():
+            project.add_dependencies(deps, group, dev or False)
+        lockfile = project.lockfile
+        project.write_lockfile(lockfile, False)
     if sync or dry_run:
         do_sync(
             project,
@@ -400,13 +409,6 @@ def do_update(
             no_self=no_self,
             hooks=hooks,
         )
-    if unconstrained and not dry_run:
-        # Need to update version constraints
-        save_version_specifiers(updated_deps, resolved, save)
-        for group, deps in updated_deps.items():
-            project.add_dependencies(deps, group, dev or False)
-        lockfile = project.lockfile
-        project.write_lockfile(lockfile, False)
 
 
 def do_remove(
